@@ -6,13 +6,13 @@ Demonstration of a DIC controlled test.
 This program is intended as a demonstration and is fully virtual.
 
 No hardware required.
+Requires the cv2 module to be installed.
 """
 
 import crappy
-import cv2
 
 if __name__ == "__main__":
-  img = cv2.imread('data/speckle.png', 0)
+  img = crappy.resources.speckle
 
   speed = 5 / 60  # mm/sec
 
@@ -24,7 +24,8 @@ if __name__ == "__main__":
 
   # Our fake machine
   machine = crappy.blocks.Fake_machine(maxstrain=17, k=5000, l0=20,
-      plastic_law=lambda exx: 0, sigma={'F(N)': 0.5})
+                                       plastic_law=lambda exx: 0,
+                                       sigma={'F(N)': 0.5})
 
   crappy.link(generator, machine)
   crappy.link(machine, generator)
