@@ -6,7 +6,6 @@
 from .autoDrive import AutoDrive
 from .block import Block
 from .camera import Camera
-from .client import Client
 from .dashboard import Dashboard
 from .discorrel import DISCorrel
 from .displayer import Displayer
@@ -26,7 +25,6 @@ from .multiplex import Multiplex
 from .pid import PID
 from .reader import Reader
 from .recorder import Recorder, Saver
-from .server import Server
 from .sink import Sink
 from .videoExtenso import Video_extenso
 from .client_server import Client_server
