@@ -4,7 +4,7 @@ from .camera import Camera
 from .._global import OptionalModule
 try:
   from . import clModule as Cl
-except ImportError:
+except (ImportError, ModuleNotFoundError):
   Cl = OptionalModule("clModule", "CameraLink module was not compiled. Please "
                                   "make sure /opt/SiliconSoftware/xxx/lib64 "
                                   "exists and reinstall Crappy")
